[CHNOSZ-commits] r253 - in pkg/CHNOSZ: . R man

noreply at r-forge.r-project.org noreply at r-forge.r-project.org
Thu Oct 12 11:10:59 CEST 2017


Author: jedick
Date: 2017-10-12 11:10:59 +0200 (Thu, 12 Oct 2017)
New Revision: 253

Modified:
   pkg/CHNOSZ/DESCRIPTION
   pkg/CHNOSZ/R/nonideal.R
   pkg/CHNOSZ/man/EOSregress.Rd
   pkg/CHNOSZ/man/IAPWS95.Rd
   pkg/CHNOSZ/man/affinity.Rd
   pkg/CHNOSZ/man/anim.Rd
   pkg/CHNOSZ/man/data.Rd
   pkg/CHNOSZ/man/eos.Rd
   pkg/CHNOSZ/man/eqdata.Rd
   pkg/CHNOSZ/man/examples.Rd
   pkg/CHNOSZ/man/extdata.Rd
   pkg/CHNOSZ/man/ionize.aa.Rd
   pkg/CHNOSZ/man/protein.info.Rd
   pkg/CHNOSZ/man/subcrt.Rd
   pkg/CHNOSZ/man/swap.basis.Rd
   pkg/CHNOSZ/man/util.data.Rd
   pkg/CHNOSZ/man/util.formula.Rd
   pkg/CHNOSZ/man/util.protein.Rd
   pkg/CHNOSZ/man/util.units.Rd
   pkg/CHNOSZ/man/water.Rd
   pkg/CHNOSZ/man/wjd.Rd
Log:
Rd files: use \degC macro in more places


Modified: pkg/CHNOSZ/DESCRIPTION
===================================================================
--- pkg/CHNOSZ/DESCRIPTION	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/DESCRIPTION	2017-10-12 09:10:59 UTC (rev 253)
@@ -1,6 +1,6 @@
 Date: 2017-10-12
 Package: CHNOSZ
-Version: 1.1.0-51
+Version: 1.1.0-52
 Title: Thermodynamic Calculations for Geobiochemistry
 Author: Jeffrey Dick
 Maintainer: Jeffrey Dick <j3ffdick at gmail.com>

Modified: pkg/CHNOSZ/R/nonideal.R
===================================================================
--- pkg/CHNOSZ/man/EOSregress.Rd	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/man/EOSregress.Rd	2017-10-12 09:10:59 UTC (rev 253)
@@ -90,7 +90,7 @@
 Here, \eqn{\sigma}{sigma} and \eqn{\xi}{xi} are calculated from a1, a2, a3 and a4 in \code{thermo$obigt} at the pressure indicated by \code{P} (default 1 bar).
 
 The original motivation for writing these functions was to explore alternatives or possible modifications to the revised Helgeson-Kirkham-Flowers equations applied to aqueous nonelectrolytes.
-As pointed out by Schulte et al., 2001, the functional forms of the equations do not permit retrieving values of the solvation parameter (\eqn{\omega}{omega}) that closely represent the observed trends in both heat capacity and volume at high temperatures (above ca. 200 \eqn{^{\circ}}{°}C).
+As pointed out by Schulte et al., 2001, the functional forms of the equations do not permit retrieving values of the solvation parameter (\eqn{\omega}{omega}) that closely represent the observed trends in both heat capacity and volume at high temperatures (above ca. 200 \degC).
 
 The examples below assume that the \eqn{\omega}{omega} parameter in the HKF functions is a constant (does not depend on T and P), as is appropriate for nonelectrolytes.
 For charged species, the variables \code{Cp_s_var} and \code{V_s_var} can be used in the regressions.

Modified: pkg/CHNOSZ/man/IAPWS95.Rd
===================================================================
--- pkg/CHNOSZ/man/IAPWS95.Rd	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/man/IAPWS95.Rd	2017-10-12 09:10:59 UTC (rev 253)
@@ -23,7 +23,7 @@
 The \code{IAPWS95} function returns values of thermodynamic properties in specific units (per gram).
 The IAPWS-95 formulation follows the triple point convention used in engineering (values of internal energy and entropy are taken to be zero at the triple point).
 
-For \code{IAPWS95} the upper temperature limit of validity is 1000 \eqn{^{\circ}}{°}C, but extrapolation to much higher temperatures is possible (Wagner and Pruss, 2002).
+For \code{IAPWS95} the upper temperature limit of validity is 1000 \degC, but extrapolation to much higher temperatures is possible (Wagner and Pruss, 2002).
 Valid pressures are from the greater of zero bar or the melting pressure at temperature to 10000 bar (with the provision for extrapolation to more extreme conditions).
 The function does not check these limits and will attempt calculations for any range of input parameters, but may return \code{NA} for properties that fail to be calculated at given temperatures and pressures and/or produce warnings or even errors when problems are encountered.
 }

Modified: pkg/CHNOSZ/man/affinity.Rd
===================================================================
--- pkg/CHNOSZ/man/affinity.Rd	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/man/affinity.Rd	2017-10-12 09:10:59 UTC (rev 253)
@@ -35,7 +35,7 @@
 For any arguments that refer to basis species, the numerical values are the logarithms of activity (or fugacity for gases) of that basis species.
 
 If \samp{T}, \samp{P}, and/or \samp{IS} are not among the \code{var}s, their constant values can be supplied in \code{T}, \code{P}, or \code{IS} (in mol kg\eqn{^{-1}}{^-1}).
-The units of \samp{T} and \samp{P} are those set by \code{\link{T.units}} and \code{\link{P.units}} (on program start-up these are \eqn{^{\circ}}{°}C and bar, respectively). 
+The units of \samp{T} and \samp{P} are those set by \code{\link{T.units}} and \code{\link{P.units}} (on program start-up these are \degC and bar, respectively). 
 \code{sout}, if provided, replaces the call to \code{\link{subcrt}}, which can greatly speed up the calculations if this intermediate result is stored by other functions.
 \code{exceed.Ttr} is passed to \code{\link{subcrt}} so that the properties of mineral phases beyond their transition temperatures can optionally be calculated.
 

Modified: pkg/CHNOSZ/man/anim.Rd
===================================================================
--- pkg/CHNOSZ/man/anim.Rd	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/man/anim.Rd	2017-10-12 09:10:59 UTC (rev 253)
@@ -37,7 +37,7 @@
 
 \code{anim.TCA} creates a series of figures showing how a logaH2O - logfO2 activity diagram for various species involved in the tricarboxylic acid (TCA) cycle changes as a function of pH.
 Alternatively, set \code{redox} to \code{list(H2=c(-20,0))} to draw a logaH2O - logaH2 diagram.
-The diagrams are made at 25 \eqn{^{\circ}}{°}C unless \code{high.T} is TRUE, in which case high-temperature (100 \eqn{^{\circ}}{°}C) stability fields are overlaid.
+The diagrams are made at 25 \degC unless \code{high.T} is TRUE, in which case high-temperature (100 \degC) stability fields are overlaid.
 
 \code{anim.carboxylase} animates equilibrium rank-activity diagrams along a combined temperature and logaH2 gradient, or makes a single plot on the default device (without conversion to animated GIF) if a single \code{temperature} is provided.
 The proteins in the calculation are 24 carboxylases from a variety of organisms.

Modified: pkg/CHNOSZ/man/data.Rd
===================================================================
--- pkg/CHNOSZ/man/data.Rd	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/man/data.Rd	2017-10-12 09:10:59 UTC (rev 253)
@@ -62,19 +62,19 @@
 
     \item \code{thermo$element}
   Dataframe containing the thermodynamic properties of elements taken from Cox et al., 1989 and Wagman et al., 1982.
-  The standard molal entropy (\eqn{S}(\code{Z})) at 25 \eqn{^{\circ}}{°}C and 1 bar for the \dQuote{element} of charge (\code{Z}) was calculated from \eqn{S}(H2,g) + 2\eqn{S}(\code{Z}) =  2\eqn{S}(H+), where the standard molal entropies of H2,g and H+ were taken from Cox et al., 1989.
+  The standard molal entropy (\eqn{S}(\code{Z})) at 25 \degC and 1 bar for the \dQuote{element} of charge (\code{Z}) was calculated from \eqn{S}(H2,g) + 2\eqn{S}(\code{Z}) =  2\eqn{S}(H+), where the standard molal entropies of H2,g and H+ were taken from Cox et al., 1989.
   The mass of \code{Z} is taken to be zero.
   Accessing this data frame using \code{\link{mass}} or \code{\link{entropy}} will select the first entry found for a given element; i.e., values from Wagman et al., 1982 will only be retrieved if the properties of the element are not found from Cox et al., 1989.
       \tabular{lll}{
       \code{element}  \tab character  \tab Symbol of element\cr
-      \code{state}  \tab character \tab Stable state of element at 25 \eqn{^{\circ}}{°}C and 1 bar\cr
+      \code{state}  \tab character \tab Stable state of element at 25 \degC and 1 bar\cr
       \code{source} \tab character \tab Source of data\cr
       \code{mass}  \tab numeric \tab Mass of element (in natural isotopic distribution;\cr
       \tab \tab referenced to a mass of 12 for \eqn{^{12}}{12}C)\cr
       \code{s}   \tab numeric \tab Entropy of the compound of the element in its stable\cr
-      \tab \tab state at 25 \eqn{^{\circ}}{°}C and 1 bar (cal K\eqn{^{-1}}{^-1} mol\eqn{^{-1}}{^-1})\cr
+      \tab \tab state at 25 \degC and 1 bar (cal K\eqn{^{-1}}{^-1} mol\eqn{^{-1}}{^-1})\cr
       \code{n}  \tab numeric \tab Number of atoms of the element in its stable\cr
-      \tab \tab compound at 25 \eqn{^{\circ}}{°}C and 1 bar
+      \tab \tab compound at 25 \degC and 1 bar
     }
 
     \item \code{thermo$obigt}
@@ -98,13 +98,13 @@
   See the vignette \emph{Thermodynamic data in CHNOSZ} for a complete description of the sources of data.
 
 In order to represent thermodynamic data for minerals with phase transitions, the higher-temperature phases of these minerals are represented as phase species that have states denoted by \samp{cr2}, \samp{cr3}, etc.
-The standard molar thermodynamic properties at 25 \eqn{^{\circ}}{°}C and 1 bar (\eqn{T_r}{Pr} and \eqn{P_r}{Pr}) of the \samp{cr2} phase species of minerals were generated by first calculating those of the \samp{cr} (lowest-T) phase species at the transition temperature (\eqn{T_{tr}}{Ttr}) and 1 bar then taking account of the volume and entropy of transition (the latter can be retrieved by combining the former with the Clausius-Clapeyron equation and values of \eqn{(dP/dT)} of transitions taken from the \acronym{SUPCRT92} data file) to calculate the standard molar entropy of the \samp{cr2} phase species at \eqn{T_{tr}}{Ttr}, and taking account of the enthalpy of transition (\eqn{{\Delta}H^{\circ}}{DeltaH0}, taken from the \acronym{SUPCRT92} data file) to calculate the standard molar enthalpy of the \samp{cr2} phase species at \eqn{T_{tr}}{Ttr}.
-The standard molar properties of the \samp{cr2} phase species at \eqn{T_{tr}}{Ttr} and 1 bar calculated in this manner were combined with the equations-of-state parameters of the species to generate values of the standard molar properties at 25 \eqn{^{\circ}}{°}C and 1 bar.
+The standard molar thermodynamic properties at 25 \degC and 1 bar (\eqn{T_r}{Pr} and \eqn{P_r}{Pr}) of the \samp{cr2} phase species of minerals were generated by first calculating those of the \samp{cr} (lowest-T) phase species at the transition temperature (\eqn{T_{tr}}{Ttr}) and 1 bar then taking account of the volume and entropy of transition (the latter can be retrieved by combining the former with the Clausius-Clapeyron equation and values of \eqn{(dP/dT)} of transitions taken from the \acronym{SUPCRT92} data file) to calculate the standard molar entropy of the \samp{cr2} phase species at \eqn{T_{tr}}{Ttr}, and taking account of the enthalpy of transition (\eqn{{\Delta}H^{\circ}}{DeltaH0}, taken from the \acronym{SUPCRT92} data file) to calculate the standard molar enthalpy of the \samp{cr2} phase species at \eqn{T_{tr}}{Ttr}.
+The standard molar properties of the \samp{cr2} phase species at \eqn{T_{tr}}{Ttr} and 1 bar calculated in this manner were combined with the equations-of-state parameters of the species to generate values of the standard molar properties at 25 \degC and 1 bar.
 This process was repeated as necessary to generate the standard molar properties of phase species represented by \samp{cr3} and \samp{cr4}, referencing at each iteration the previously calculated values of the standard molar properties of the lower-temperature phase species (i.e., \samp{cr2} and \samp{cr3}).
 A consequence of tabulating the standard molar thermodynamic properties of the phase species is that the values of \eqn{(dP/dT)} and \eqn{{\Delta}H^{\circ}}{DeltaH0} of phase transitions can be calculated using the equations of state and therefore do not need to be stored in the thermodynamic database.
 However, the transition temperatures (\eqn{T_{tr}}{Ttr}) generally can not be assessed by comparing the Gibbs energies of phase species and are tabulated in the database.
 
-The identification of species and their standard molal thermodynamic properties at 25 \eqn{{^\circ}}{°}C and 1 bar are located in the first 12 columns of \code{thermo$obigt}:
+The identification of species and their standard molal thermodynamic properties at 25 \degC and 1 bar are located in the first 12 columns of \code{thermo$obigt}:
 
     \tabular{lll}{
       \code{name}     \tab character \tab Species name\cr
@@ -237,7 +237,7 @@
 \references{
 Cox, J. D., Wagman, D. D. and Medvedev, V. A., eds. (1989) \emph{CODATA Key Values for Thermodynamics}. Hemisphere Publishing Corporation, New York, 271 p. \url{http://www.worldcat.org/oclc/18559968}
 
-Johnson, J. W., Oelkers, E. H. and Helgeson, H. C. (1992) SUPCRT92: A software package for calculating the standard molal thermodynamic properties of minerals, gases, aqueous species, and reactions from 1 to 5000 bar and 0 to 1000\eqn{^{\circ}}{°}C. \emph{Comp. Geosci.} \bold{18}, 899--947. \url{https://doi.org/10.1016/0098-3004(92)90029-Q}
+Johnson, J. W., Oelkers, E. H. and Helgeson, H. C. (1992) SUPCRT92: A software package for calculating the standard molal thermodynamic properties of minerals, gases, aqueous species, and reactions from 1 to 5000 bar and 0 to 1000\degC. \emph{Comp. Geosci.} \bold{18}, 899--947. \url{https://doi.org/10.1016/0098-3004(92)90029-Q}
 
 Shock, E. L. et al. {1998} \emph{SLOP98.dat} (computer data file). http://geopig.asu.edu/supcrt92_data/slop98.dat, accessed on 2005-11-05. Current location: \url{http://geopig.asu.edu/?q=tools}.
 

Modified: pkg/CHNOSZ/man/eos.Rd
===================================================================
--- pkg/CHNOSZ/man/eos.Rd	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/man/eos.Rd	2017-10-12 09:10:59 UTC (rev 253)
@@ -18,7 +18,7 @@
   \item{parameters}{dataframe, species parameters as one or more rows from \code{thermo$obigt}}
   \item{T}{numeric, temperature(s) at which to calculate properties (K)}
   \item{P}{numeric, pressure(s) at which to calculate properties (bar)}
-  \item{contrib}{character, which contributions to consider in the revised HKF equations equations of state: (\code{n})onsolvation, (\code{s})olvation (the \eqn{\omega}{omega} terms), or (o)rigination contributions (i.e., the property itself at 25 \eqn{^{\circ}}{°}C and 1 bar). Default is \code{c("n","s","o")}, for all contributions}
+  \item{contrib}{character, which contributions to consider in the revised HKF equations equations of state: (\code{n})onsolvation, (\code{s})olvation (the \eqn{\omega}{omega} terms), or (o)rigination contributions (i.e., the property itself at 25 \degC and 1 bar). Default is \code{c("n","s","o")}, for all contributions}
   \item{H2O.props}{character, properties to calculate for water}
 }
 
@@ -45,7 +45,7 @@
 }
 
 \section{Warning}{
-The temperature and pressure range of validity of the revised HKF equations of state for aqueous species corresponds to the stability region of liquid water or the supercritical fluid at conditions between 0 to 1000 \eqn{^{\circ}}{°}C and 1 to 5000 bar (Tanger and Helgeson, 1988; Shock and Helgeson, 1988).
+The temperature and pressure range of validity of the revised HKF equations of state for aqueous species corresponds to the stability region of liquid water or the supercritical fluid at conditions between 0 to 1000 \degC and 1 to 5000 bar (Tanger and Helgeson, 1988; Shock and Helgeson, 1988).
 The \code{hkf} function does not check these limits and will compute properties as long as the requisite electrostatic properties of water are available. There are conceptually no temperature limits (other than 0 Kelvin) for the validity of the \code{cgl} equations of state.
 However, the actual working upper temperature limits correspond to the temperatures of phase transitions of minerals or to those temperatures beyond which extrapolations from experimental data become highly uncertain.
 These temperature limits are stored in the thermodynamic database for some minerals, but \code{cgl} ignores them; however, \code{\link{subcrt}} warns if they are exceeded.
@@ -93,9 +93,9 @@
 
   Robie, R. A. and Hemingway, B. S. (1995) \emph{Thermodynamic Properties of Minerals and Related Substances at 298.15 K and 1 Bar (\eqn{10^5} Pascals) Pressure and at Higher Temperatures}. U. S. Geol. Surv., Bull. 2131, 461 p. \url{http://www.worldcat.org/oclc/32590140}
 
-  Shock, E. L. and Helgeson, H. C. (1988) Calculation of the thermodynamic and transport properties of aqueous species at high pressures and temperatures: Correlation algorithms for ionic species and equation of state predictions to 5 kb and 1000\eqn{^{\circ}}{°}C. \emph{Geochim. Cosmochim. Acta} \bold{52}, 2009--2036. \url{https://doi.org/10.1016/0016-7037(88)90181-0}
+  Shock, E. L. and Helgeson, H. C. (1988) Calculation of the thermodynamic and transport properties of aqueous species at high pressures and temperatures: Correlation algorithms for ionic species and equation of state predictions to 5 kb and 1000\degC. \emph{Geochim. Cosmochim. Acta} \bold{52}, 2009--2036. \url{https://doi.org/10.1016/0016-7037(88)90181-0}
   
-  Shock, E. L., Oelkers, E. H., Johnson, J. W., Sverjensky, D. A. and Helgeson, H. C. (1992) Calculation of the thermodynamic properties of aqueous species at high pressures and temperatures: Effective electrostatic radii, dissociation constants and standard partial molal properties to 1000 \eqn{^{\circ}}{°}C and 5 kbar. \emph{J. Chem. Soc. Faraday Trans.} \bold{88}, 803--826. \url{https://doi.org/10.1039/FT9928800803}
+  Shock, E. L., Oelkers, E. H., Johnson, J. W., Sverjensky, D. A. and Helgeson, H. C. (1992) Calculation of the thermodynamic properties of aqueous species at high pressures and temperatures: Effective electrostatic radii, dissociation constants and standard partial molal properties to 1000 \degC and 5 kbar. \emph{J. Chem. Soc. Faraday Trans.} \bold{88}, 803--826. \url{https://doi.org/10.1039/FT9928800803}
 
   Tanger, J. C. IV and Helgeson, H. C. (1988) Calculation of the thermodynamic and transport properties of aqueous species at high pressures and temperatures: Revised equations of state for the standard partial molal properties of ions and electrolytes. \emph{Am. J. Sci.} \bold{288}, 19--98. \url{https://doi.org/10.2475/ajs.288.1.19}
 

Modified: pkg/CHNOSZ/man/eqdata.Rd
===================================================================
--- pkg/CHNOSZ/man/eqdata.Rd	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/man/eqdata.Rd	2017-10-12 09:10:59 UTC (rev 253)
@@ -29,7 +29,7 @@
   }
 
 
-  The result of the function is a data frame (returned invisibly), with columns \code{zi} (reaction progress), \code{T} (temperature in \eqn{^{\circ}}{°}C), \code{aH2O} (activity of water) and one column for each of the requested \code{species} or, for speciation of basis species, one column for each unique species found in all of the speciation summary blocks for that basis species. Values are listed as NA (not available) for species or phases that are not present in the EQ6 output at any of the increments of reaction progress. 
+  The result of the function is a data frame (returned invisibly), with columns \code{zi} (reaction progress), \code{T} (temperature in \degC, \code{aH2O} (activity of water) and one column for each of the requested \code{species} or, for speciation of basis species, one column for each unique species found in all of the speciation summary blocks for that basis species. Values are listed as NA (not available) for species or phases that are not present in the EQ6 output at any of the increments of reaction progress. 
 
   If \code{outfile} is TRUE, the result is saved in a file named like \samp{file}.\samp{property}.\code{csv}, in the same directory as \code{file}. The name of the \code{outfile} can be provided to override this naming scheme, or this argument can be set to FALSE or NULL, to turn off writing the result to a file.
 

Modified: pkg/CHNOSZ/man/examples.Rd
===================================================================
--- pkg/CHNOSZ/man/examples.Rd	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/man/examples.Rd	2017-10-12 09:10:59 UTC (rev 253)
@@ -92,7 +92,7 @@
 
 Schulte, M. D. and Shock, E. L. (1995) Thermodynamics of Strecker synthesis in hydrothermal systems. \emph{Orig. Life Evol. Biosph.} \bold{25}, 161--173. \url{https://doi.org/10.1007/BF01581580}
 
-Shock, E. L., Oelkers, E. H., Johnson, J. W., Sverjensky, D. A. and Helgeson, H. C. (1992) Calculation of the thermodynamic properties of aqueous species at high pressures and temperatures: Effective electrostatic radii, dissociation constants and standard partial molal properties to 1000 \eqn{^{\circ}}{°}C and 5 kbar. \emph{J. Chem. Soc. Faraday Trans.} \bold{88}, 803--826. \url{https://doi.org/10.1039/FT9928800803}
+Shock, E. L., Oelkers, E. H., Johnson, J. W., Sverjensky, D. A. and Helgeson, H. C. (1992) Calculation of the thermodynamic properties of aqueous species at high pressures and temperatures: Effective electrostatic radii, dissociation constants and standard partial molal properties to 1000 \degC and 5 kbar. \emph{J. Chem. Soc. Faraday Trans.} \bold{88}, 803--826. \url{https://doi.org/10.1039/FT9928800803}
 
 Stumm, W. and Morgan, J. J. (1996) \emph{Aquatic Chemistry: Chemical Equilibria and Rates in Natural Waters}, John Wiley & Sons, New York, 1040 p. \url{http://www.worldcat.org/oclc/31754493}
 

Modified: pkg/CHNOSZ/man/extdata.Rd
===================================================================
--- pkg/CHNOSZ/man/extdata.Rd	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/man/extdata.Rd	2017-10-12 09:10:59 UTC (rev 253)
@@ -35,12 +35,12 @@
 
   Files in \code{cpetc} contain experimental and calculated thermodynamic and environmental data:
   \itemize{
-    \item \code{PM90.csv} Heat capacities of four unfolded aqueous proteins taken from Privalov and Makhatadze, 1990. Temperature in \eqn{^{\circ}}{°}C is in the first column, and heat capacities of the proteins in J mol\eqn{^{-1}}{^-1} K\eqn{^{-1}}{^-1} in the remaining columns. See \code{\link{ionize.aa}} and the vignette \code{anintro.Rmd} for examples that uses this file.
+    \item \code{PM90.csv} Heat capacities of four unfolded aqueous proteins taken from Privalov and Makhatadze, 1990. Temperature in \degC is in the first column, and heat capacities of the proteins in J mol\eqn{^{-1}}{^-1} K\eqn{^{-1}}{^-1} in the remaining columns. See \code{\link{ionize.aa}} and the vignette \code{anintro.Rmd} for examples that uses this file.
     \item \code{RH95.csv} Heat capacity data for iron taken from Robie and Hemingway, 1995. Temperature in Kelvin is in the first column, heat capacity in J K\eqn{^{-1}}{^-1} mol\eqn{^{-1}}{^-1} in the second. See \code{\link{subcrt}} for an example that uses this file.
     \item \code{RT71.csv} pH titration measurements for unfolded lysozyme (\samp{LYSC_CHICK}) taken from Roxby and Tanford, 1971. pH is in the first column, net charge in the second. See \code{\link{ionize.aa}} for an example that uses this file.
     \item \code{SOJSH.csv} Experimental equilibrium constants for the reaction NaCl(aq) = Na+ + Cl- as a function of temperature and pressure taken from Fig. 1 of Shock et al., 1992. Data were extracted from the figure using g3data (\url{http://www.frantz.fi/software/g3data.php}). See \code{demo("NaCl")} for an example that uses this file.
     \item \code{Cp.CH4.HW97.csv}, \code{V.CH4.HWM96.csv} Apparent molar heat capacities and volumes of CH4 in dilute aqueous solutions reported by Hnědkovský and Wood, 1997 and Hnědkovský et al., 1996. See \code{\link{EOSregress}} and the vignette \code{eos-regress.Rmd} for examples that use these files.
-    \item \code{SC10_Rainbow.csv} Values of temperature (\eqn{^{\circ}}{°}C), pH and logarithms of activity of \CO2, \H2, \NH4plus, \H2S and \CH4 for mixing of seawater and hydrothermal fluid at Rainbow field (Mid-Atlantic Ridge), taken from Shock and Canovas, 2010. See the vignette \code{anintro.Rmd} for an example that uses this file.
+    \item \code{SC10_Rainbow.csv} Values of temperature (\degC, pH and logarithms of activity of \CO2, \H2, \NH4plus, \H2S and \CH4 for mixing of seawater and hydrothermal fluid at Rainbow field (Mid-Atlantic Ridge), taken from Shock and Canovas, 2010. See the vignette \code{anintro.Rmd} for an example that uses this file.
     \item \code{SS98_Fig5a.csv}, \code{SS98_Fig5b.csv} Values of logarithm of fugacity of \O2 and pH as a function of temperature for mixing of seawater and hydrothermal fluid, digitized from Figs. 5a and b of Shock and Schulte, 1998. See the vignette \code{anintro.Rmd} for an example that uses this file.
     \item \code{rubisco.csv} UniProt IDs for Rubisco, ranges of optimal growth temperature of organisms, domain and name of organisms, and URL of reference for growth temperature, from Dick, 2014. See the vignette \code{anintro.Rmd} for an example that uses this file.
   }
@@ -153,7 +153,7 @@
 
 Shock, E. and Canovas, P. (2010) The potential for abiotic organic synthesis and biosynthesis at seafloor hydrothermal systems. \emph{Geofluids} \bold{10}, 161--192. \url{https://doi.org/10.1111/j.1468-8123.2010.00277.x}
 
-Shock, E. L., Oelkers, E. H., Johnson, J. W., Sverjensky, D. A. and Helgeson, H. C. (1992) Calculation of the thermodynamic properties of aqueous species at high pressures and temperatures: Effective electrostatic radii, dissociation constants and standard partial molal properties to 1000 \eqn{^{\circ}}{°}C and 5 kbar. \emph{J. Chem. Soc. Faraday Trans.} \bold{88}, 803--826. \url{https://doi.org/10.1039/FT9928800803}
+Shock, E. L., Oelkers, E. H., Johnson, J. W., Sverjensky, D. A. and Helgeson, H. C. (1992) Calculation of the thermodynamic properties of aqueous species at high pressures and temperatures: Effective electrostatic radii, dissociation constants and standard partial molal properties to 1000 \degC and 5 kbar. \emph{J. Chem. Soc. Faraday Trans.} \bold{88}, 803--826. \url{https://doi.org/10.1039/FT9928800803}
 
 Shock, E. L. and Schulte, M. D. (1998) Organic synthesis during fluid mixing in hydrothermal systems. \emph{J. Geophys. Res.} \bold{103}, 28513--28527. \url{https://doi.org/10.1029/98JE02142}
 

Modified: pkg/CHNOSZ/man/ionize.aa.Rd
===================================================================
--- pkg/CHNOSZ/man/ionize.aa.Rd	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/man/ionize.aa.Rd	2017-10-12 09:10:59 UTC (rev 253)
@@ -14,8 +14,8 @@
 \arguments{
   \item{aa}{data frame, amino acid composition in the format of \code{thermo$protein}}
   \item{property}{character, property to calculate}
-  \item{T}{numeric, temperature in \eqn{^{\circ}}{°}C}
-  \item{P}{numeric, pressure in bar, or \samp{Psat} for vapor pressure of \H2O above 100 \eqn{^{\circ}}{°}C}
+  \item{T}{numeric, temperature in \degC}
+  \item{P}{numeric, pressure in bar, or \samp{Psat} for vapor pressure of \H2O above 100 \degC}
   \item{pH}{numeric, pH}
   \item{ret.val}{character, return the indicated value from intermediate calculations}
   \item{suppress.Cys}{logical, suppress (ignore) the ionization of the cysteine groups?}

Modified: pkg/CHNOSZ/man/protein.info.Rd
===================================================================
--- pkg/CHNOSZ/man/protein.info.Rd	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/man/protein.info.Rd	2017-10-12 09:10:59 UTC (rev 253)
@@ -29,7 +29,7 @@
   \item{regexp}{logical, find matches using regular expressions?}
   \item{normalize}{logical, return per-residue values (those of the proteins divided by their lengths)?}
   \item{state}{character, physical state}
-  \item{T}{numeric, temperature in \eqn{^{\circ}}{°}C}
+  \item{T}{numeric, temperature in \degC}
   \item{loga.protein}{numeric, decimal logarithms of reference activities of proteins}
   \item{digits}{integer, number of significant digits (see \code{\link{signif}})}
 }

Modified: pkg/CHNOSZ/man/subcrt.Rd
===================================================================
--- pkg/CHNOSZ/man/subcrt.Rd	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/man/subcrt.Rd	2017-10-12 09:10:59 UTC (rev 253)
@@ -82,7 +82,7 @@
 Values of \code{logK} of reactions calculated for \code{IS} not equal to zero are consistent with the apparent Gibbs energies of the charged aqueous species.
 
 \code{subcrt} is modeled after the functionality of the \acronym{SUPCRT92} package (Johnson et al., 1992).
[TRUNCATED]

To get the complete diff run:
    svnlook diff /svnroot/chnosz -r 253


More information about the CHNOSZ-commits mailing list
--- pkg/CHNOSZ/R/nonideal.R	2017-10-12 08:21:01 UTC (rev 252)
+++ pkg/CHNOSZ/R/nonideal.R	2017-10-12 09:10:59 UTC (rev 253)
@@ -1,49 +1,55 @@
 # CHNOSZ/nonideal.R
 # first version of function: 20080308 jmd
 # moved to nonideal.R from util.misc.R 20151107
+# added Helgeson method 20171012
 
-nonideal <- function(species,proptable,IS,T) {
+nonideal <- function(species, proptable, IS, T, P) {
   thermo <- get("thermo")
   # generate nonideal contributions to thermodynamic properties
   # number of species, same length as proptable list
   # T in Kelvin, same length as nrows of proptables
-  # a function that does a lot of the work
-  loggamma2 <- function(Z,I,T,prop='log') {
-    # extended Debye-Huckel equation ('log')
-    # and its partial derivatives ('G','H','S','Cp')
+
+  # function to calculate extended Debye-Huckel equation and derivatives using Alberty's parameters
+  Alberty <- function(Z, I, T, prop = "log") {
+    # extended Debye-Huckel equation ("log")
+    # and its partial derivatives ("G","H","S","Cp")
     # T in Kelvin
-    B <- 1.6
+    B <- 1.6 # L^0.5 mol^-0.5 (Alberty, 2003 p. 47)
     # equation for A from Clarke and Glew, 1980
     #A <- expression(-16.39023 + 261.3371/T + 3.3689633*log(T)- 1.437167*(T/100) + 0.111995*(T/100)^2)
-    # equation for alpha from Alberty, 2003 p. 48
-    A <- alpha <- expression(1.10708 - 1.54508E-3 * T + 5.95584E-6 * T^2)
+    # equation for A (alpha) from Alberty, 2003 p. 48
+    A <- expression(1.10708 - 1.54508E-3 * T + 5.95584E-6 * T^2)
     # from examples for deriv to take first and higher-order derivatives
-    DD <- function(expr,name, order = 1) {
+    DD <- function(expr, name, order = 1) {
       if(order < 1) stop("'order' must be >= 1")
-      if(order == 1) D(expr,name)
+      if(order == 1) D(expr, name)
       else DD(D(expr, name), name, order - 1)
     }
     # Alberty, 2003 Eq. 3.6-1
-    loggamma <- function(a,Z,I,B) { - a * Z^2 * I^(1/2) / (1 + B * I^(1/2)) }
+    loggamma <- function(a, Z, I, B) - a * Z^2 * I^(1/2) / (1 + B * I^(1/2))
     # TODO: check the following equations 20080208 jmd
     R <- 1.9872  # gas constant, cal K^-1 mol^-1
-    if(prop=='log') return(loggamma(eval(A),Z,I,B))
-    else if(prop=='G') return(R * T * loggamma(eval(A),Z,I,B))
-    else if(prop=='H') return(R * T^2 * loggamma(eval(DD(A,'T',1)),Z,I,B))
-    else if(prop=='S') return(- R * T * loggamma(eval(DD(A,'T',1)),Z,I,B))
-    else if(prop=='Cp') return(R * T^2 *loggamma(eval(DD(A,'T',2)),Z,I,B))
+    if(prop=="log") return(loggamma(eval(A), Z, I, B))
+    else if(prop=="G") return(R * T * loggamma(eval(A), Z, I, B))
+    else if(prop=="H") return(R * T^2 * loggamma(eval(DD(A, "T", 1)), Z, I, B))
+    else if(prop=="S") return(- R * T * loggamma(eval(DD(A, "T", 1)), Z, I, B))
+    else if(prop=="Cp") return(R * T^2 *loggamma(eval(DD(A, "T", 2)), Z, I, B))
   }
+  
+  # function for Debye-Huckel equation with B-dot extended term parameter (Helgeson, 1969)
   Helgeson <- function() {
     # "distance of closest approach" of ions in NaCl solutions
     # HKF81 Table 2
     acirc <- 3.72  # Angstrom
   }
 
-  if(!is.numeric(species[[1]])) species <- info(species,'aq')
+  # get species indices
+  if(!is.numeric(species[[1]])) species <- info(species, "aq")
+  iH <- info("H+")
+  ie <- info("e-")
   proptable <- as.list(proptable)
-  # which gamma function to use
-  #mlg <- get(paste('loggamma',which,sep=''))
   ndid <- 0
+  # loop over species
   for(i in 1:length(species)) {
     myprops <- proptable[[i]]
     # get the charge from the chemical formula
@@ -53,27 +59,26 @@
     # don't do anything for neutral species
     if(Z==0) next
     # to keep unit activity coefficients of the proton and electron
-    if(species[i] == info("H+") & thermo$opt$ideal.H) next
-    if(species[i] == info("e-") & thermo$opt$ideal.e) next
+    if(species[i] == iH & get("thermo")$opt$ideal.H) next
+    if(species[i] == ie & get("thermo")$opt$ideal.e) next
     didit <- FALSE
     for(j in 1:ncol(myprops)) {
-      #if(colnames(myprops)[j]=='G') myprops[,j] <- myprops[,j] + R * T * mlg(Z,IS,convert(T,'C'))
-      cname <- colnames(myprops)[j]
-      if(cname %in% c('G','H','S','Cp')) {
-        myprops[,j] <- myprops[,j] + loggamma2(Z,IS,T,cname)
+      pname <- colnames(myprops)[j]
+      if(pname %in% c("G", "H", "S", "Cp")) {
+        myprops[,j] <- myprops[,j] + Alberty(Z, IS, T, pname)
         didit <- TRUE
       }
     }
     # append a loggam column if we did any nonideal calculations of thermodynamic properties
-    if(didit) myprops <- cbind(myprops,loggam=loggamma2(Z,IS,T))
+    if(didit) myprops <- cbind(myprops, loggam = Alberty(Z, IS, T))
     proptable[[i]] <- myprops
     if(didit) ndid <- ndid + 1
   }
-  if(ndid > 0) message(paste('nonideal:',ndid,'species were nonideal'))
+  if(ndid > 0) message(paste("nonideal:", ndid, "species were nonideal"))
   return(proptable)
 }
 
-Bdot <- function(TC=25, P=1, showsplines="") {
+Bdot <- function(TC = 25, P = 1, showsplines = "") {
   # 20171012 calculate B-dot (bgamma) using P, T, points from:
   # Helgeson, 1969 (doi:10.2475/ajs.267.7.729)
   # Helgeson et al., 1981 (doi:10.2475/ajs.281.10.1249)

Modified: pkg/CHNOSZ/man/EOSregress.Rd
===================================================================